pro cbar,x0,y0,vrange,crange,inc,pd,missing=missing,charthick=charthick,$
  charsize=charsize,ysize=ysize,xsize=xsize,label=label,tcolor=tcolor
;******************************************************************************
; Program:       cbar
;
; Modifications: 11-Mar-95 Original Version
;
; Purpose:       put a horizontal color bar on the display device at specified
;		 normal coordinates. also indicate missing data value color
;
; Parameters:	
;	x0,y0  	   normalized lower left coords of bar
;	vrange 	   array of lower & upper bound of data values
;	crange 	   array of lower & upper bound of color table entries to use
;       inc        the increment step of the number scale in value units
;       pd         output plot device (0 = X, 1=ps)
;
; Optional Parameters:
;       missing    color table entry used in image to designate missing data
;	charsize   character size on the number scale
;       charthick  thickness of characters 
;       ysize      vertical size of color bar in normalized coords
;       xsize      horizontal size of color bar in normalized coords
;       label      a string containing a label for the color bar
;	tcolor     the color table index to use in drawing a box around
;	 	      the color bar and drawing text labels
;
; Returns:       A Beautiful color bar on your output device!
;******************************************************************************
if keyword_set(missing) eq 0 then missing=999.
if keyword_set(charsize) eq 0 then charsize=1.
if keyword_set(charthick) eq 0 then charthick=1.
if keyword_set(xsize) eq 0 then xsize=.5
if keyword_set(ysize) eq 0 then ysize=.025
if keyword_set(label) eq 0 then label=''
if keyword_set(tcolor) eq 0 then begin
;  if pd eq 0 then tcolor=!d.n_colors-1
;  if pd eq 1 then tcolor=1
   tcolor = 0
endif
charx=float(!d.x_ch_size)/float(!d.x_vsize)  ; normalized width of characters
chary=float(!d.y_ch_size)/float(!d.y_vsize)  ; normalized height of characters

inc0=vrange(1)
s0=vrange(0)
s1=vrange(1)
frmt='(e9.3)'
nzs=fix(alog10(inc*1.01))
if nzs lt 0 and nzs gt -4 then begin
  frmt='(i8.'+string(form='(i1)',-nzs+1)+')'  ; used on scale
endif
if nzs ge 0 and nzs le 3 then frmt='(i8.1)'   

mg=6
smax=string(vrange(1),form=frmt)
smax=strcompress(smax,/remove_all)
smin=string(vrange(0),form=frmt)
smin=strcompress(smin,/remove_all)
lablen=strlen(smax) > strlen(smin)    

;draw the color bar
x1=x0+xsize
y1=y0+ysize
ysd=ysize*!d.y_vsize
y3=y0-2.5*chary;*charsize
y4=y0-3*chary;*charsize
xpix=(x1-x0)*!d.x_vsize
if pd eq 1 then begin	; special handling for post-script
  xpix=crange(1)-crange(0)
  ysd=2
endif

;if xpix gt crange(1) then xpix=crange(1)
tv,bytscl(indgen(xpix) # replicate(1,ysd), top=crange(1)-crange(0))+crange(0), $
   x0,y0,xsize=xsize,ysize=ysize,/NORMAL

;draw a box around the color bar
boxx=[x0,x1,x1,x0,x0]
boxy=[y0,y0,y1,y1,y0]
PLOTS,boxx,boxy,/NORMAL,color=tcolor

;draw vertical lines at selected values
nval=fix((s1-s0)/inc+.1)   ; the number of ticks to draw
denom=vrange(1)-vrange(0)  ; range of vals
for ival=0,nval do begin
  val=s0+inc*float(ival)
  ss=(val-vrange(0))/denom ; normalized position along the length of the bar 
  if ss ge 0 and ss le 1 then begin
    xval=x0+(x1-x0)*ss
    sval=string(val,form=frmt)
    sval=strcompress(sval,/remove_all)
    plots,[xval,xval],[y0,y1],/NORMAL,color=tcolor
    xyouts,xval,y3+.02,sval,/NORMAL,charsize=charsize,color=tcolor,$
	charthick=charthick,alignment=0.5
  endif
endfor      
xyouts,(x0+x1)/2.,y4,label,alignment=0.5,color=tcolor,charthick=charthick,$
   /NORMAL,charsize=charsize

;draw the missing data box
if (missing ne 999.) then begin
  xstart=x0+xsize+.075*xsize
  xend=xstart+.05*xsize
  xpix=(xend-xstart)*!d.x_vsize+1
  if pd eq 1 then xpix=2 ; post script
  disparr=bytscl(indgen(xpix) # replicate(1,ysd))
  disparr(*,*)=missing
  tv,disparr,xstart,y0,xsize=(xend-xstart),ysize=ysize,/NORMAL
  boxx=[xstart,xend,xend,xstart,xstart]
  PLOTS,boxx,boxy,/NORMAL,color=tcolor
  XYOUTS,xstart+(xend-xstart)/2.,y3,'Missing',color=tcolor,/NORMAL,alignment=0.5
endif 
;break
end
