;#####################################################################################
;
; (C) Cooperative Institute for Meteorological Satellite Studies, 2003
;
; NAME: University of Wisconsin Infrared Simulator (UWIS) Version 1.1
;
; CREATED: Justin Sieglaff, CIMSS/SSEC 19 MAY 2003
;	   justin.sieglaff@ssec.wisc.edu OR
;	   jmsieglaff@yahoo.com
;	   Subject: UWIS
;
; PURPOSE: Program to simulate IR imager/sounder bands using AIRS or NASTI data
;
; REQUIREMENTS:  IDL v5.0 or higher (square bracket for arrays)
;                uwis.pro, nasti.pro, airs.pro, run_uwis, eff_wn.pro
;                cbar.pro, nasti_to_binary.pro
;                imagemap.pro, saveimage.pro (From Liam Gumley)
;                is_ncdf.pro, read_ncdf.pro (From CIMSS)
;                read_swath_l1_airs.pro ((From NASA/JPL)
;
; CALLING SEQUENCE: From IDL prompt: @run_uwis
;
; INPUT: No inputs are required when starting program, but user will be prompted for 
;        various input files during program execution
;
;	 SRF ASCII File must have format:  WAVENUM  RESPONSE
;        With no headers!  Ideally the SRF will have 0.1 cm-1 resolution.
;
;        AIRS channel properties files can be found at:
;        http://daac.gsfc.nasa.gov/atmodyn/airs/airs_documentation.html
;        Recent AIRS chan prop files are included and have *.ANC extensions
;	 
;	 AIRS data can be obtained at:
;	 http://daac.gsfc.nasa.gov/data/download/AIRS_DP/
;
;        AIRS and NASTI* data must be in native data formats (hdf and netCDF)
;        *For first time use NASTI data in netCDF then use generated binary file
;
; OUTPUT: Convoluted radiance or brightness temp image
;
; LIMITATIONS: None known.  Be sure to see limitations of imagemap.pro
;
; NOTES: It is recommended to obtain the AIRS Channel properties file that 
;        corresponds to the version of your AIRS data.
;
;        UWIS creates a binary file with radiance, frequency, lat and lon from the
;        three sections of a NASTI flight for later use.  This is done to save
;        time reading and sorting the NASTI data.
;
;        The idea for this program came from working with a similar program by
;        Mike Griffin of MIT/LL.  For a copy of Mike's AHABS please email him at
;        griffin@ll.mit.edu
;
;        The effective wavenumbers, band corrections and constants used to calculate 
;        brightness temp are calculated with code from Mat Gunshor and Hal Woolf.
;
;	 The range for brightness temperature is sufficient for most cases.  If the
;	 range does not fit your needs you may change the values at the top of
;	 airs.pro or nasti.pro (cbar_values=[X1,X2]) depending on which dataset you
;	 are using.
;
;	Please report bugs and send suggestions to the email address above.
;
;
;#####################################################################################

PRO UWIS
;%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
;%                               Main Program                                       %
;%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
print, '**************************************************************************'
print, '**** Welcome to the University of Wisconsin Infrared Simulator (UWIS) ****'
print, '**************************** Version 1.0 *********************************'
print, '**************************************************************************'
print, ' '
data_type=' '
repeat begin
	print, '**************************************************************************'
	print, 'Type AIRS for AIRS data simulations or NASTI for NASTI data simulatations: '
	read, data_type
	print, '**************************************************************************'
	case data_type of
		'AIRS': airs
		'airs': airs
		'NASTI': nasti
		'nasti': nasti
		else: print, 'Data type not supported, try again'
	endcase
endrep until (data_type eq 'AIRS' $
	or data_type eq 'airs' $
	or data_type eq 'NASTI' $
	or data_type eq 'nasti')
END
